==> InferenceSMR_1.0.tar.gz: InferenceSMR/man/req.objects.Rd <==
\name{req.objects}
\keyword{internal}
\alias{req.objects}
\docType{data}
\title{
Required objects to run some examples
}
\description{
Contains pre-built objects used to run some examples. Those items simplify some examples.
}
\usage{data(req.objects)}
\format{
  The format is:
List of 5
 $ contribution:List of 4
  ..$ :'data.frame':	1022 obs. of  9 variables:
  .. ..$ Group.1: num [1:1022] 0 0.5 1 1.5 2 2.5 3 0 0.5 1 ...
  .. ..$ Group.2: num [1:1022] 3 3 3 3 3 3 3 4 4 4 ...
  .. ..$ Group.3: num [1:1022] 70 70 70 70 70 70 70 70 70 70 ...
  .. ..$ Group.4: num [1:1022] 0 0 0 0 0 0 0 0 0 0 ...
  .. ..$ Group.5: num [1:1022] 0 0 0 0 0 0 0 0 0 0 ...
  .. ..$ Group.6: num [1:1022] 0 0 0 0 0 0 0 0 0 0 ...
  .. ..$ Group.7: num [1:1022] 0 0 0 0 0 0 0 0 0 0 ...
  .. ..$ Group.8: num [1:1022] 0 0 0 0 0 0 0 0 0 0 ...
  .. ..$ x      : num [1:1022] 11 16.5 11 11 20 20 11 8 16 34 ...
  ..$ : int 2
  ..$ : int 5
  ..$ : num 0.5
 $ incid       : num [1:156, 1:4] 0.018 0.0171 0.0266 0.0122 0.0183 ...
 $ cox         :List of 18
  ..$ coefficients     : Named num [1:5] -0.3843 0.3169 0.0076 0.1483 0.1751
  .. ..- attr(*, "names")= chr [1:5] "year" "age1" "age2" "age3" ...
  ..$ var              : num [1:5, 1:5] 0.104866 0.003629 -0.003322 -0.000495 -0.004334 ...
  ..$ loglik           : num [1:2] -361 -360
  ..$ score            : num 2.19
  ..$ iter             : int 4
  ..$ linear.predictors: num [1:697] 0.1638 -0.2281 -0.0798 -0.2281 0.3313 ...
  ..$ residuals        : Named num [1:697] -0.0179 -0.0877 -0.1096 -0.1518 -0.1014 ...
  .. ..- attr(*, "names")= chr [1:697] "1" "2" "3" "4" ...
  ..$ means            : num [1:5] 0.5968 0.0861 0.1449 0.1578 0.122
  ..$ concordance      : Named num [1:5] 13077 9278 4675 0 2084
  .. ..- attr(*, "names")= chr [1:5] "concordant" "discordant" "tied.risk" "tied.time" ...
  ..$ method           : chr "breslow"
  ..$ n                : int 697
  ..$ nevent           : num 60
  ..$ terms            :Classes 'terms', 'formula' length 3 Surv(time = followONS, event = deathBC, type = "right") ~ year + age1 + age2 + age3 + age4
  .. .. ..- attr(*, "variables")= language list(Surv(time = followONS, event = deathBC, type = "right"), year, age1, age2, age3, age4)
  .. .. ..- attr(*, "factors")= int [1:6, 1:5] 0 1 0 0 0 0 0 0 1 0 ...
  .. .. .. ..- attr(*, "dimnames")=List of 2
  .. .. .. .. ..$ : chr [1:6] "Surv(time = followONS, event = deathBC, type = \"right\")" "year" "age1" "age2" ...
  .. .. .. .. ..$ : chr [1:5] "year" "age1" "age2" "age3" ...
  .. .. ..- attr(*, "term.labels")= chr [1:5] "year" "age1" "age2" "age3" ...
  .. .. ..- attr(*, "specials")=Dotted pair list of 3
  .. .. .. ..$ strata : NULL
  .. .. .. ..$ cluster: NULL
  .. .. .. ..$ tt     : NULL
  .. .. ..- attr(*, "order")= int [1:5] 1 1 1 1 1
  .. .. ..- attr(*, "intercept")= int 1
  .. .. ..- attr(*, "response")= int 1
  .. .. ..- attr(*, ".Environment")=<environment: R_GlobalEnv> 
  .. .. ..- attr(*, "predvars")= language list(Surv(time = followONS, event = deathBC, type = "right"), year, age1, age2, age3, age4)
  .. .. ..- attr(*, "dataClasses")= Named chr [1:6] "nmatrix.2" "numeric" "numeric" "numeric" ...
  .. .. .. ..- attr(*, "names")= chr [1:6] "Surv(time = followONS, event = deathBC, type = \"right\")" "year" "age1" "age2" ...
  ..$ assign           :List of 5
  .. ..$ year: num 1
  .. ..$ age1: num 2
  .. ..$ age2: num 3
  .. ..$ age3: num 4
  .. ..$ age4: num 5
  ..$ wald.test        : num 2.17
  ..$ y                : Surv [1:697, 1:2] 0.7957+ 3.4669+ 3.7693+ 5.5679+ 2.0462+ 2.1702  0.7686+ 2.7796+ 3.7853+ 5.2374+ ...
  .. ..- attr(*, "dimnames")=List of 2
  .. .. ..$ : chr [1:697] "1" "2" "3" "4" ...
  .. .. ..$ : chr [1:2] "time" "status"
  .. ..- attr(*, "type")= chr "right"
  ..$ formula          :Class 'formula' length 3 Surv(time = followONS, event = deathBC, type = "right") ~ year + age1 + age2 + age3 + age4
  .. .. ..- attr(*, ".Environment")=<environment: R_GlobalEnv> 
  ..$ call             : language coxph(formula = Surv(time = followONS, event = deathBC, type = "right") ~ year + age1 + age2 + age3 + age4, data = cox.data, control = coxph.control(iter.max = 100),      method = "breslow")
  ..- attr(*, "class")= chr "coxph"
 $ covnames    : chr [1:5] "year" "age1" "age2" "age3" ...
 $ cox.data    :'data.frame':	697 obs. of  7 variables:
  ..$ followONS: num [1:697] 0.796 3.467 3.769 5.568 2.046 ...
  ..$ deathBC  : num [1:697] 0 0 0 0 0 1 0 0 0 0 ...
  ..$ year     : num [1:697] 0 1 1 1 0 1 0 0 1 1 ...
  ..$ age1     : num [1:697] 0 0 0 0 0 0 0 0 0 0 ...
  ..$ age2     : num [1:697] 1 0 0 0 0 0 0 0 0 0 ...
  ..$ age3     : num [1:697] 0 0 1 0 0 0 0 1 0 1 ...
  ..$ age4     : num [1:697] 0 0 0 0 1 0 0 0 0 0 ...
}
\keyword{datasets}

==> InferenceSMR_1.0.1.tar.gz: InferenceSMR/man/req.objects.Rd <==
\title{
Required objects to run some examples
}\name{req.objects}\alias{req.objects}\keyword{internal}\keyword{datasets}\description{
Contains pre-built objects used to run some examples. Those items simplify some examples.
}
\usage{data(req.objects)}
\format{
  The format is:
List of 5
 $ contribution:List of 4
  ..$ :'data.frame':    1022 obs. of  9 variables:
  .. ..$ Group.1: num [1:1022] 0 0.5 1 1.5 2 2.5 3 0 0.5 1 ...
  .. ..$ Group.2: num [1:1022] 3 3 3 3 3 3 3 4 4 4 ...
  .. ..$ Group.3: num [1:1022] 70 70 70 70 70 70 70 70 70 70 ...
  .. ..$ Group.4: num [1:1022] 0 0 0 0 0 0 0 0 0 0 ...
  .. ..$ Group.5: num [1:1022] 0 0 0 0 0 0 0 0 0 0 ...
  .. ..$ Group.6: num [1:1022] 0 0 0 0 0 0 0 0 0 0 ...
  .. ..$ Group.7: num [1:1022] 0 0 0 0 0 0 0 0 0 0 ...
  .. ..$ Group.8: num [1:1022] 0 0 0 0 0 0 0 0 0 0 ...
  .. ..$ x      : num [1:1022] 11 16.5 11 11 20 20 11 8 16 34 ...
  ..$ : int 2
  ..$ : int 5
  ..$ : num 0.5
 $ incid       : num [1:156, 1:4] 0.018 0.0171 0.0266 0.0122 0.0183 ...
 $ cox         :List of 18
  ..$ coefficients     : Named num [1:5] -0.3843 0.3169 0.0076 0.1483 0.1751
  .. ..- attr(*, "names")= chr [1:5] "year" "age1" "age2" "age3" ...
  ..$ var              : num [1:5, 1:5] 0.104866 0.003629 -0.003322 -0.000495 -0.004334 ...
  ..$ loglik           : num [1:2] -361 -360
  ..$ score            : num 2.19
  ..$ iter             : int 4
  ..$ linear.predictors: num [1:697] 0.1638 -0.2281 -0.0798 -0.2281 0.3313 ...
  ..$ residuals        : Named num [1:697] -0.0179 -0.0877 -0.1096 -0.1518 -0.1014 ...
  .. ..- attr(*, "names")= chr [1:697] "1" "2" "3" "4" ...
  ..$ means            : num [1:5] 0.5968 0.0861 0.1449 0.1578 0.122
  ..$ concordance      : Named num [1:5] 13077 9278 4675 0 2084
  .. ..- attr(*, "names")= chr [1:5] "concordant" "discordant" "tied.risk" "tied.time" ...
  ..$ method           : chr "breslow"
  ..$ n                : int 697
  ..$ nevent           : num 60
  ..$ terms            :Classes 'terms', 'formula' length 3 Surv(time = followONS, event = deathBC, type = "right") ~ year + age1 + age2 + age3 + age4
  .. .. ..- attr(*, "variables")= language list(Surv(time = followONS, event = deathBC, type = "right"), year, age1, age2, age3, age4)
  .. .. ..- attr(*, "factors")= int [1:6, 1:5] 0 1 0 0 0 0 0 0 1 0 ...
  .. .. .. ..- attr(*, "dimnames")=List of 2
  .. .. .. .. ..$ : chr [1:6] "Surv(time = followONS, event = deathBC, type = \"right\")" "year" "age1" "age2" ...
  .. .. .. .. ..$ : chr [1:5] "year" "age1" "age2" "age3" ...
  .. .. ..- attr(*, "term.labels")= chr [1:5] "year" "age1" "age2" "age3" ...
  .. .. ..- attr(*, "specials")=Dotted pair list of 3
  .. .. .. ..$ strata : NULL
  .. .. .. ..$ cluster: NULL
  .. .. .. ..$ tt     : NULL
  .. .. ..- attr(*, "order")= int [1:5] 1 1 1 1 1
  .. .. ..- attr(*, "intercept")= int 1
  .. .. ..- attr(*, "response")= int 1
  .. .. ..- attr(*, ".Environment")=<environment: R_GlobalEnv> 
  .. .. ..- attr(*, "predvars")= language list(Surv(time = followONS, event = deathBC, type = "right"), year, age1, age2, age3, age4)
  .. .. ..- attr(*, "dataClasses")= Named chr [1:6] "nmatrix.2" "numeric" "numeric" "numeric" ...
  .. .. .. ..- attr(*, "names")= chr [1:6] "Surv(time = followONS, event = deathBC, type = \"right\")" "year" "age1" "age2" ...
  ..$ assign           :List of 5
  .. ..$ year: num 1
  .. ..$ age1: num 2
  .. ..$ age2: num 3
  .. ..$ age3: num 4
  .. ..$ age4: num 5
  ..$ wald.test        : num 2.17
  ..$ y                : Surv [1:697, 1:2] 0.7957+ 3.4669+ 3.7693+ 5.5679+ 2.0462+ 2.1702  0.7686+ 2.7796+ 3.7853+ 5.2374+ ...
  .. ..- attr(*, "dimnames")=List of 2
  .. .. ..$ : chr [1:697] "1" "2" "3" "4" ...
  .. .. ..$ : chr [1:2] "time" "status"
  .. ..- attr(*, "type")= chr "right"
  ..$ formula          :Class 'formula' length 3 Surv(time = followONS, event = deathBC, type = "right") ~ year + age1 + age2 + age3 + age4
  .. .. ..- attr(*, ".Environment")=<environment: R_GlobalEnv> 
  ..$ call             : language coxph(formula = Surv(time = followONS, event = deathBC, type = "right") ~ year + age1 + age2 + age3 + age4, data = cox.data, control = coxph.control(iter.max = 100),      method = "breslow")
  ..- attr(*, "class")= chr "coxph"
 $ covnames    : chr [1:5] "year" "age1" "age2" "age3" ...
 $ cox.data    :'data.frame':   697 obs. of  7 variables:
  ..$ followONS: num [1:697] 0.796 3.467 3.769 5.568 2.046 ...
  ..$ deathBC  : num [1:697] 0 0 0 0 0 1 0 0 0 0 ...
  ..$ year     : num [1:697] 0 1 1 1 0 1 0 0 1 1 ...
  ..$ age1     : num [1:697] 0 0 0 0 0 0 0 0 0 0 ...
  ..$ age2     : num [1:697] 1 0 0 0 0 0 0 0 0 0 ...
  ..$ age3     : num [1:697] 0 0 1 0 0 0 0 1 0 1 ...
  ..$ age4     : num [1:697] 0 0 0 0 1 0 0 0 0 0 ...
}
